function [ys,check] = nonlinearomega_steadystate(ys,exe) %(junk,ys,exe) % (ys,exe)
%global M_ lgy_  

% computes the steady state for the NK_baseline.mod and uses a numerical
% solver to do so
% Inputs: 
%   - ys        [vector] vector of initial values for the steady state of
%                   the endogenous variables
%   - exo       [vector] vector of values for the exogenous variables
%
% Output: 
%   - ys        [vector] vector of steady state values fpr the the endogenous variables
%   - check     [scalar] set to 0 if steady state computation worked and to
%                    1 of not (allows to impos restriction on parameters)

%global M_ params paramlist param_switch sensitivity_switch paramfile_name

global M_ lgy_ 

% read out parameters to access them with their name
NumberOfParameters = M_.param_nbr;
for ii = 1:NumberOfParameters
  paramname = deblank(M_.param_names(ii,:));
  eval([ paramname ' = M_.params(' int2str(ii) ');']);
end

% initialize indicator
check = 0;
options=optimset(); % set options for numerical solver
% country one simple parameters kept fixed

%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%
%% Dependent Parameters

c1grmuzoss =  c1grmuzss/c1grmuoss; 
c1muoss = c1grmuoss;
c1muzss = c1grmuzss;
c1muzoss = c1grmuzss/c1grmuoss;
c1muoss = c1grmuoss;
c1muzss = c1grmuzss;
c1muzoss = c1muzss/c1muoss;
c1grmuzoss = c1grmuzss/c1grmuoss;
c2grmuzss = c1grmuzss;
c2grmuoss = c1grmuoss;
c2grmuzoss = c1grmuzss/c1grmuoss;
c2muoss = c1grmuoss;
c2muzss = c1grmuzss;
c2muzoss = c1grmuzss/ c1grmuoss; 
c1beta = c1muzss/1.01;       % discount factor that yields a 4% interest rate
c2beta = c1beta; 
c1rhoc = 1/(c1telast -1); 
c1rhoo = 1/(c1oelast -1);
c1rhov = 1/(c1kelast -1);  
c2shareiy = c1shareiy;      %investment share of gross output
c2sharegy = c1sharegy;      %government spending share of gross output
c1rhoi = c1rhoc;%elasticity of substitution investment imports  
%c1phioy   = c1phioc;
c2rhoc   = c1rhoc; 
c2rhoo   = c1rhoo;
c2rhov   = c1rhov;
%c2sigma = c1sigma;
%c2chi = c1chi;  % determines labor supply elasticity
%c2alphaop = c1alphaop;
c2deltao = c1deltao;
%c2phimc = c1phimc;           % trade adjustment costs
%c2rhozc1 = c1rhozc1;%THIS
%c2rhozc2 = c1rhozc2;%THIS
% persistence parameters for shock process
c2rhozi = c1rhozi;%THIS
%c2rhogy = c1rhogy;%THIS
%c2rhomuoc1 = c1rhomuoc1;%THIS
%c2rhomuoc2 = c1rhomuoc2;%THIS
%c2rhomuc = c1rhomuc;%THIs
%c2rhoomegacm1 = c1rhoomegacm1;%THIS
c2rhoomegacm2 = c1rhoomegacm2;%THIS
%c2psii = c1psii;      % investmetn adjustment costs
%c2vkappa = c1vkappa;      % consumption habits
c2scalezierr = c1scalezierr;%THIS
c1shareky = 1/(1-(1-c1delta)/c1muzss)*c1shareiy; 
c1shareoop = (c1beta*(1-c1alphaop)/c1alphaop/(c1muoss-c1beta*(1-c1deltao)))^(1-c1alphaop);%0.9999;
c1shareopos =  (1-c1beta/c1muzss*c1muzoss*(1-c1deltao))/(c1beta*(1-c1alphaop)/c1alphaop);%0.0000405808; 
c1shareowo =  1/c1shareoop+(1-(1-c1deltao)/c1muoss)*c1muoss*(c1muoss*c1shareopos)^-c1alphaop;%0.403047947;  
c1pwoss = c1alphaop * c1shareoop;%0.99906854;  
c1shareowy = c1shareowy_nominal/c1pwoss;%0.040637853; 
c1shareyoy = c1shareowy * 0.3;
c1shareoy = c1shareowy/c1shareowo;
c1shareoyy = c1shareoy*(1-1/(1+c1ratiooyoc));%0.02926573; 
c1sharevy = 1-c1shareoyy;%0.97073427;         
c1shareopow  =   (1/(c1shareoop))/c1shareowo;
c1shareoiow  =  1-1/c1shareoop/c1shareowo; 
c1rkstar = c1muzss/c1beta - 1 + c1delta; 
c2rkstar = c2muzss/c2beta - 1 + c2delta; 
c2ratiooyoc = c1ratiooyoc; 
c2shareoop = (c2beta*(1-c2alphaop)/c2alphaop/(c2muoss-c2beta*(1-c2deltao)))^(1-c2alphaop);%0.9999;
c2pwoss = c2alphaop * c2shareoop;    % steady state value of wholesale price
c2shareowy = c2shareowy_nominal/c2pwoss;%0.035840191;
c2shareopos = (1-c2beta/c2muzss*c2muzoss*(1-c2deltao))/(c2beta*(1-c2alphaop)/c2alphaop);%0.0000405808; 
c2shareowo = 1/c2shareoop+(1-(1-c2deltao)/c2muoss)*c2muoss*(c2muoss*c2shareopos)^-c2alphaop;%0.403047947;
c2shareoy = c2shareowy/c2shareowo;
c2shareoyy =  c2shareoy*(1-1/(1+c2ratiooyoc));%0.057830975 ;
c2sharevy  =  1-c2shareoyy;%0.942169025 ;
c2shareky = 1/(1-(1-c2delta)/c2muzss)*c2shareiy;      % capital to output ratio
c1omegak = 1/(1-(1-c1delta)/c1muzss)*(c1rkstar)^((1+c1rhov)/c1rhov)/c1muzss*c1shareiy/c1sharevy;
c2omegak = 1/(1-(1-c2delta)/c2muzss)*(c2rkstar)^((1+c2rhov)/c2rhov)/c2muzss*c2shareiy/c2sharevy;
c1sharely = c1sharevy*(1-c1omegak*c1rkstar^(-1/c1rhov))^(1+c1rhov);
c2sharely = c2sharevy*(1-c2omegak*c2rkstar^(-1/c2rhov))^(1+c2rhov);
c1yss = 1/(c1sharely/c1less);
c2yss = 1/(c2sharely/c2less);
c2shareyoy = c2shareowy + (c1shareowy-c1shareyoy)*c1relc2*c1yss/c2yss;
c2sharecy = 1+c2shareoy-c2shareowy*c2pwoss+c2pwoss*c2shareyoy-c2shareoyy-c2shareiy-c2sharegy;
c2scaleshockgyerr = c1scaleshockgyerr;
c2shareopow  =  (1/(c2shareoop))/c2shareowo;%0.000101049;  
c2shareoiow =  1-1/c2shareoop/c2shareowo;%0.999898951; 
% c2 share of total oil production
c2shareoprod = c2shareyoy/(c2shareyoy+c1shareyoy*c1relc2*c1yss/c2yss);
% c2 share of total oil consumption
c2shareocon = c2shareowy/(c2shareowy + c1shareowy*c1relc2*c1yss/c2yss);
% Goods import shares
c2sharemy = c1sharemy*c1relc2*c1yss/c2yss + (c1shareowy-c1shareyoy)*c1pwoss*c1relc2*c1yss/c2yss;
c1sharexy = c1sharemy+(c1shareowy-c1shareyoy)*c1pwoss;
c2sharexy = c2sharemy-(c1shareowy-c1shareyoy)*c1pwoss*c1relc2*c1yss/c2yss;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% country one def parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

c1labshare = c1less/(1-c1less);
%c1phioc   = 0.5^(1/(c1halflife+2))/((1+c1rhoo)/c1rhoo*(1-0.5^(1/(c1halflife+2))));
%%%% continue from here
c1sharecy = 1+c1shareoy-c1shareowy*c1pwoss+c1pwoss*c1shareyoy-c1shareoyy-c1shareiy-c1sharegy;  % consumption share of gross output
c1shareocc = (c1shareoy-c1shareoyy)/c1sharecy;
c1sharecnc = 1-c1shareocc;
c1sharemcm = c1sharecnc*c1sharecy/(c1sharecnc*c1sharecy+c1shareiy);
c1sharemim = 1-c1sharemcm;
c1sharemccn = c1sharemy*c1sharemcm/(c1sharecy)/c1sharecnc;
c1sharemii = c1sharemy*c1sharemim/c1shareiy;
c1ratiomimc = c1sharemim/c1sharemcm;
c1sharengdpny = 1 - c1shareoyy + c1shareoy- c1pwoss*c1shareowy + c1pwoss*c1shareyoy ;
%c1sharengdpny = 1 - c1shareoyy  + c1pwoss*c1shareyoy ;
c1mugdpss = (c1muzss+ ( -c1shareoyy+c1shareoy - c1pwoss*c1shareowy + c1pwoss*c1shareyoy)*c1muoss )...
           /( 1 + ( -c1shareoyy+c1shareoy - c1pwoss*c1shareowy + c1pwoss*c1shareyoy) );
       
c1omegaoc = c1shareocc; %given by def_parm_assembled (c1shareoy-c1shareoyy)/c1sharecy; %
c1omegacc = 1-c1omegaoc; 
c1omegamc =  c1sharemccn; %given by def_parm_assembled  c1sharemy*c1sharemcm/(c1sharecy)/c1sharecnc; 
c1omegac = 1-c1omegamc; 
c1omegami = c1sharemii;
c1omegai  = 1-c1omegami;
c1omegaoy = c1shareoyy;
c1omegavy = 1-c1omegaoy;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% country 2 def parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

c2labshare = c2less/(1-c2less);
%c2phioc   = 0.5^(1/(c2halflife+2))/((1+c2rhoo)/c2rhoo*(1-0.5^(1/(c2halflife+2)))); 
%c2phioy   = c2phioc;%THIS
c2sharecy = 1+c2shareoy-c2shareowy*c2pwoss+c2pwoss*c2shareyoy-c2shareoyy-c2shareiy-c2sharegy;  % consumption share of gross output
c2shareocc = (c2shareoy-c2shareoyy)/c2sharecy;
c2sharecnc = 1-c2shareocc;
c2sharemcm = c2sharecnc*c2sharecy/(c2sharecnc*c2sharecy+c2shareiy);
c2sharemim = 1-c2sharemcm;
c2sharemccn= c2sharemy*c2sharemcm/(c2sharecy)/c2sharecnc;
c2sharemii = c2sharemy*c2sharemim/c2shareiy;
c2ratiomimc = c2sharemim/c2sharemcm;
%c2sharengdpny = 1 - c2shareoyy  + c2pwoss*c2shareyoy ;
c2sharengdpny = 1 - c2shareoyy + c2shareoy- c2pwoss*c2shareowy + c2pwoss*c2shareyoy ;
c2mugdpss = (c2muzss+ ( -c2shareoyy+c2shareoy - c2pwoss*c2shareowy + c2pwoss*c2shareyoy)*c2muoss )...
           /( 1 + ( -c2shareoyy+c2shareoy - c2pwoss*c2shareowy + c2pwoss*c2shareyoy) );

c2omegaoc = c2shareocc; %c2shareocc given by def_parm_assembled (c2shareoy-c2shareoyy)/c2sharecy; 
c2omegacc = 1-c2omegaoc; 
c2omegamc = c2sharemccn; %given by def_parm_assembled c2sharemy*c2sharemcm/(c2sharecy)/c2sharecnc; 
c2omegac = 1-c2omegamc; 
c2omegami = c2sharemii;
c2omegai  = 1-c2omegami;
c2omegaoy = c2shareoyy;
c2omegavy = 1-c2omegaoy;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% additional parameters in sticky price model 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%c1kappaw = (1-c1xiw)*(1-c1beta*c1xiw)/c1xiw/(1+(c1jrtheta-1)*(1+c1thetaw)/c1thetaw);
c2iotap = c1iotap;
c2iotaw = c1iotaw;
c2xip = c1xip;
c2thetap = c1thetap;
%c2rhothetapvar = c1rhothetapvar;%SEE THIS ESTIMATION PRIOR
%c2scalethetapvarerr = c1scalethetapvarerr;%SEE THIS ESTIMATION PRIOR
%c2rhopitar = c1rhopitar;%SEE THIS ESTIMATION PRIOR
%c2scalepitarerr = c1scalepitarerr;%SEE THIS ESTIMATION PRIOR
c2xiw = c1xiw;
c2thetaw = c1thetaw;
%c2rhothetawvar = c1rhothetawvar;%SEE THIS ESTIMATION PRIOR
%c2scalethetawvarerr = c1scalethetawvarerr;%SEE THIS ESTIMATION PRIOR
%c2kappaw = (1-c2xiw)*(1-c2beta*c2xiw)/c2xiw/(1+(c2jrtheta-1)*(1+c2thetaw)/c2thetaw);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  steadyoilmodJRstickycombodynarenonlinear_c1.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

c1lss = c1less;
c1yss = 1/(c1sharely/c1less); % given by def_parm_assembled
c1rpopdss = 1;
c1ydss = c1yss;
c1iss = c1shareiy*c1ydss;
c1kss = 1/(1-(1-c1delta)/c1muzss)*c1shareiy*c1ydss;
c1css = c1sharecy*c1ydss;
c1cness = c1omegacc*c1css;
c1ocss = c1omegaoc*c1css;
c1cdss = c1omegac*c1cness;
c1mcss = c1omegamc*c1cness;
c1idss = c1omegai*c1iss;
c1miss = c1omegami*c1iss;
c1oyss = c1omegaoy*c1ydss;
c1vss = c1omegavy*c1ydss;
c1oss = c1ocss+c1oyss;
c1mss = c1miss+c1mcss;
c1gss = c1sharegy*c1ydss;
c1xss = c1sharexy*c1ydss;
c1owss = c1shareowy*c1ydss;
c1opss = c1shareopow*c1owss;
c1osss = 1/c1shareopos*c1opss; 
c1oiss = c1shareoiow*c1owss;
c1rpwopdss = c1pwoss;
c1logdeltagdpss = 0;
c1rngdpyss = 1  - c1rpwopdss* c1oyss / c1ydss + c1rpwopdss * c1shareyoy*c1ydss / c1ydss;
c1tbalss = (c1xss-c1mss+c1rpwopdss*(c1shareyoy*c1ydss-c1owss))/c1ydss;
c1gtbalss = (c1xss-c1mss)/c1ydss;

%prices
c1dpdss = 0;
c1pitar = 0;
c1dwss = 0;
c1lambdaqss = (c1css-c1vkappa/c1muzss*c1css)^(-1);
c1rkss = c1muzss/c1beta-1+c1delta;
c1wss = c1rkss/((c1omegak*c1sharevy/c1shareky*c1muzss)/(c1omegal*c1sharevy/c1sharely))^(c1rhov/(1+c1rhov));
c1rrsss = 1/(c1beta/c1muzss)-1;
c1rsss = 1/(c1beta/c1muzss)-1;
c1rpipdss = 1;
c1rpcpdss = 1;
c1rpnepdss = 1;
c1rpmipdss = 1;
c1rpmcpdss = 1;
c1qss = 1;
c1tauw = c1thetaw;
c1taup = c1thetap;
c1wdesss = (1+c1tauw)/(1+c1thetaw)*c1wss;
c1rmcpdss = (1+c1taup)/(1+c1thetap);
%c1chi0ss = (c1wdesss)*(c1lambdaqss)/((1-(c1lss))^(-c1chi));
c1chi0 = (c1wdesss)*(c1lambdaqss)/((1-(c1lss))^(-c1chi));
c1rerss = 1;
c1bss = 0;
%c1phibparm = c1phib;  
c1zcss = 0;
c1zclagss = 0;
c1ziss = 0;
c1yoss = 0;
c1lagyoss = 0;
c1dyoss = 0;%c1muzoss;
c1muocss = 0;
c1lagmuocss = 0;
c1mucss = 0;
c1omegacmss = 0;
c1lagomegacmss = 0;
c1omegaimss = c1omegacmss;
c1thetapvarss = 0;
c1thetawvarss = 0;
c1pitarss = 0;
c1zwss = 0;
c1zss = c1zcss + c1zwss;
c1zwlagss = c1zwss;
c1muowss = 0;
c1muowlagss = c1muowss;
c1muoss = c1muocss + c1muowss;
c1shockgyss = 0;
c1welfss = (log(c1css-c1vkappa/c1grmuzss*c1css)+ c1chi0/(1-c1chi)*(1-c1lss)^(1-c1chi))/(1-c1beta);

%quantities
c1l_potss = c1less;
c1y_potss = 1/(c1sharely/c1less); % given by def_parm_assembled
c1rpopd_potss = 1;
c1yd_potss = c1y_potss;
c1i_potss = c1shareiy*c1yd_potss;
c1k_potss = 1/(1-(1-c1delta)/c1muzss)*c1shareiy*c1yd_potss;
c1c_potss = c1sharecy*c1yd_potss;
c1cne_potss = c1omegacc*c1c_potss;
c1oc_potss = c1omegaoc*c1c_potss;
c1cd_potss = c1omegac*c1cne_potss;
c1mc_potss = c1omegamc*c1cne_potss;
c1id_potss = c1omegai*c1i_potss;
c1mi_potss = c1omegami*c1i_potss;
c1omegaoy = c1shareoyy;
c1omegavy = 1-c1omegaoy;
c1oy_potss = c1omegaoy*c1yd_potss;
c1v_potss = c1omegavy*c1yd_potss;
c1o_potss = c1oc_potss+c1oy_potss;
c1m_potss = c1mi_potss+c1mc_potss;
c1g_potss = c1sharegy*c1yd_potss;
c1x_potss = c1sharexy*c1yd_potss;
c1ow_potss = c1shareowy*c1yd_potss;
c1op_potss = c1shareopow*c1ow_potss;
c1os_potss = 1/c1shareopos*c1op_potss; 
c1oi_potss = c1shareoiow*c1ow_potss;
c1rpwopd_potss = c1pwoss;
c1logdeltagdp_potss = 0;
c1rngdpy_potss = 1  - c1rpwopd_potss* c1oy_potss / c1yd_potss + c1rpwopd_potss * c1shareyoy*c1yd_potss / c1yd_potss;
c1tbal_potss = (c1x_potss-c1m_potss+c1rpwopd_potss*(c1shareyoy*c1yd_potss-c1ow_potss))/c1yd_potss;
c1gtbal_potss = (c1x_potss-c1m_potss)/c1yd_potss;

%prices
c1dpd_potss = 0;
c1pitar = 0;
c1dw_potss = 0;
c1lambdaq_potss = (c1c_potss-c1vkappa/c1muzss*c1c_potss)^(-1);
c1rk_potss = c1muzss/c1beta-1+c1delta;
c1w_potss = c1rk_potss/((c1omegak*c1sharevy/c1shareky*c1muzss)/(c1omegal*c1sharevy/c1sharely))^(c1rhov/(1+c1rhov));
c1rrs_potss = 1/(c1beta/c1muzss)-1;
c1rs_potss = 1/(c1beta/c1muzss)-1;
c1rpipd_potss = 1;
c1rpcpd_potss = 1;
c1rpnepd_potss = 1;
c1rpmipd_potss = 1;
c1rpmcpd_potss = 1;
c1q_potss = 1;
c1tauw = c1thetaw;
c1taup = c1thetap;
c1wdes_potss = (1+c1tauw)/(1+c1thetaw)*c1w_potss;
c1rmcpd_potss = (1+c1taup)/(1+c1thetap);
%c1chi0ss = (c1wdesss)*(c1lambdaqss)/((1-(c1lss))^(-c1chi));
c1chi0 = (c1wdesss)*(c1lambdaqss)/((1-(c1lss))^(-c1chi));
%c1rhoi = c1rhoc;
c1rer_potss = 1;
c1b_potss = 0;
%c1phibparm = c1phib;  
c1zc_potss = 0;
c1zclag_potss = 0;
c1zi_potss = 0;
c1yo_potss = 0;
c1lagyo_potss = 0;
c1dyo_potss = 0;%c1muzoss;
c1muoc_potss = 0;
c1lagmuoc_potss = 0;
c1muc_potss = 0;
c1omegacm_potss = 0;
c1lagomegacm_potss = 0;
c1omegaim_potss = c1omegacm_potss;
c1thetapvar_potss = 0;
c1thetawvar_potss = 0;
c1pitar_potss = 0;
c1zw_potss = 0;
c1z_potss = c1zc_potss + c1zw_potss;
c1zwlag_potss= c1zw_potss;
c1muow_potss = 0;
c1muowlag_potss = c1muow_potss;
c1muo_potss = c1muoc_potss + c1muow_potss;
c1shockgy_potss = 0;
%c1welf_potss = (log(c1c_potss-c1vkappa/c1grmuzss*c1c_potss)+ c1chi0/(1-c1chi)*(1-c1l_potss)^(1-c1chi))/(1-c1beta);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  steadyoilmodJRstickycombodynarenonlinear_c2.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

c2lss = c2less;
c2yss = 1/(c2sharely/c2less); % given by def_parm_assembled
c2rpopdss = 1;
c2ydss = c2yss;
c2iss = c2shareiy*c2ydss;
c2kss = 1/(1-(1-c2delta)/c2muzss)*c2shareiy*c2ydss;
c2css = c2sharecy*c2ydss;
c2cness = c2omegacc*c2css;
c2ocss = c2omegaoc*c2css;
c2cdss = c2omegac*c2cness;
c2mcss = c2omegamc*c2cness;
c2idss = c2omegai*c2iss;
c2miss = c2omegami*c2iss;
c2oyss = c2omegaoy*c2ydss;
c2vss = c2omegavy*c2ydss;
c2oss = c2ocss+c2oyss;
c2mss = c2miss+c2mcss;
c2gss = c2sharegy*c2ydss;
c2xss = c2sharexy*c2ydss;
c2owss = c2shareowy*c2ydss;
c2opss = c2shareopow*c2owss;
c2osss = 1/c2shareopos*c2opss; 
c2oiss = c2shareoiow*c2owss;
c2rpwopdss = c2pwoss;
c2logdeltagdpss = 0;
c2rngdpyss = 1 - c2rpwopdss* c2oyss / c2ydss + c2rpwopdss * c2shareyoy*c2ydss / c2ydss;
c2tbalss = (c2xss-c2mss+c2rpwopdss*(c2shareyoy*c2ydss-c2owss))/c2ydss;
c2gtbalss = (c2xss-c2mss)/c2ydss;

%prices
c2dpdss = 0;
c2pitar = 0;
c2dwss = 0;
c2lambdaqss = (c2css-c2vkappa/c2muzss*c2css)^(-1);
c2rkss = c2muzss/c2beta-1+c2delta;
c2wss = c2rkss/((c2omegak*c2sharevy/c2shareky*c2muzss)/(c2omegal*c2sharevy/c2sharely))^(c2rhov/(1+c2rhov));
c2rrsss = 1/(c2beta/c2muzss)-1;
c2rsss = 1/(c2beta/c2muzss)-1;
c2rpipdss = 1;
c2rpcpdss = 1;
c2rpnepdss = 1;
c2rpmipdss = 1;
c2rpmcpdss = 1;
c2qss = 1;
c2tauw = c2thetaw;
c2taup = c2thetap;
c2wdesss = (1+c2tauw)/(1+c2thetaw)*c2wss;
c2rmcpdss = (1+c2taup)/(1+c2thetap);
%c2chi0ss = (c2wdesss)*(c2lambdaqss)/((1-(c2lss))^(-c2chi));
c2chi0 = (c2wdesss)*(c2lambdaqss)/((1-(c2lss))^(-c2chi));
%c2rhoi = c2rhoc;
c2rerss = 1;
c2bss = 0;
c2zcss = 0;
c2zclagss = 0;
c2ziss = 0;
c2yoss = 0;
c2lagyoss = 0;
c2dyoss = 0; %c2muzoss;%0;
c2muocss = 0;
c2lagmuocss = 0;
c2mucss = 0;
c2omegacmss = 0;
c2lagomegacmss = 0;
c2omegaimss = c2omegacmss;
c2thetapvarss = 0;
c2thetawvarss = 0;
c2pitarss = 0;
c2zwss = 0;
c2zss = c2zcss + c2zwss;
c2zwlagss = c2zwss;
c2muowss = 0;
c2muowlagss = c2muowss;
c2muoss = c2muocss + c2muowss;
c2shockgyss = 0;
%c2pistar = c1pistar;
c2welfss = (log(c2css-c2vkappa/c2grmuzss*c2css)+ c2chi0/(1-c2chi)*(1-c2lss)^(1-c2chi))/(1-c2beta);
c2l_potss = c2less;
c2y_potss = 1/(c2sharely/c2less); % given by def_parm_assembled
c2rpopd_potss = 1;
c2yd_potss = c2y_potss;
c2i_potss = c2shareiy*c2yd_potss;
c2k_potss = 1/(1-(1-c2delta)/c2muzss)*c2shareiy*c2yd_potss;
c2c_potss = c2sharecy*c2yd_potss;
c2cne_potss = c2omegacc*c2c_potss;
c2oc_potss = c2omegaoc*c2c_potss;
c2cd_potss = c2omegac*c2cne_potss;
c2mc_potss = c2omegamc*c2cne_potss;
c2id_potss = c2omegai*c2i_potss;
c2mi_potss = c2omegami*c2i_potss;
c2omegaoy = c2shareoyy;
c2omegavy = 1-c2omegaoy;
c2oy_potss = c2omegaoy*c2yd_potss;
c2v_potss = c2omegavy*c2yd_potss;
c2o_potss = c2oc_potss+c2oy_potss;
c2m_potss = c2mi_potss+c2mc_potss;
c2g_potss = c2sharegy*c2yd_potss;
c2x_potss = c2sharexy*c2yd_potss;
c2ow_potss = c2shareowy*c2yd_potss;
c2op_potss = c2shareopow*c2ow_potss;
c2os_potss = 1/c2shareopos*c2op_potss; 
c2oi_potss = c2shareoiow*c2ow_potss;
c2rpwopd_potss = c2pwoss;
c2logdeltagdp_potss = 0;
c2rngdpy_potss = 1  - c2rpwopd_potss* c2oy_potss / c2yd_potss + c2rpwopd_potss * c2shareyoy*c2yd_potss / c2yd_potss;
c2tbal_potss = (c2x_potss-c2m_potss+c2rpwopd_potss*(c2shareyoy*c2yd_potss-c2ow_potss))/c2yd_potss;
c2gtbal_potss = (c2x_potss-c2m_potss)/c2yd_potss;

%prices
c2dpd_potss = 0;
c2pitar = 0;
c2dw_potss = 0;
c2lambdaq_potss = (c2c_potss-c2vkappa/c2muzss*c2c_potss)^(-1);
c2rk_potss = c2muzss/c2beta-1+c2delta;
c2w_potss = c2rk_potss/((c2omegak*c2sharevy/c2shareky*c2muzss)/(c2omegal*c2sharevy/c2sharely))^(c2rhov/(1+c2rhov));
c2rrs_potss = 1/(c2beta/c2muzss)-1;
c2rs_potss = 1/(c2beta/c2muzss)-1;
c2rpipd_potss = 1;
c2rpcpd_potss = 1;
c2rpnepd_potss = 1;
c2rpmipd_potss = 1;
c2rpmcpd_potss = 1;
c2q_potss = 1;
c2tauw = c2thetaw;
c2taup = c2thetap;
c2wdes_potss = (1+c2tauw)/(1+c2thetaw)*c2w_potss;
c2rmcpd_potss = (1+c2taup)/(1+c2thetap);
%c2chi0ss = (c2wdesss)*(c2lambdaqss)/((1-(c2lss))^(-c2chi));
c2chi0 = (c2wdesss)*(c2lambdaqss)/((1-(c2lss))^(-c2chi));
%c2rhoi = c2rhoc;
c2rer_potss = 1;
c2b_potss = 0;
c2zc_potss = 0;
c2zclag_potss = 0;
c2zi_potss = 0;
c2yo_potss = 0;
c2lagyo_potss = 0;
c2dyo_potss = 0;%c2muzoss;
c2muoc_potss = 0;
c2lagmuoc_potss = 0;
c2muc_potss = 0;
c2omegacm_potss = 0;
c2lagomegacm_potss = 0;
c2omegaim_potss = c2omegacm_potss;
c2thetapvar_potss = 0;
c2thetawvar_potss = 0;
c2pitar_potss = 0;
c2zw_potss= 0;
c2z_potss = c2zc_potss + c2zw_potss;
c2zwlag_potss = c2zw_potss;
c2muow_potss = 0;
c2muowlag_potss = c2muow_potss;
c2muo_potss = c2muoc_potss + c2muow_potss;
c2shockgy_potss = 0;
%c2pistar = c1pistar;
%c2welf_potss = (log(c2c_potss-c2vkappa/c2grmuzss*c2c_potss)+ c2chi0/(1-c2chi)*(1-c2l_potss)^(1-c2chi))/(1-c2beta);


%VARS
%country1
c1welf = c1welfss;
c2welf = c2welfss;
c1lambdaq = log(c1lambdaqss);
c1q = log(c1qss);
c1i = log(c1iss);
c1k = log(c1kss);
c1c = log(c1css);
c1cne = log(c1cness);
c1cd = log(c1cdss);
c1mc = log(c1mcss);
c1oc = log(c1ocss);
c1id = log(c1idss);
c1rpipd = log(c1rpipdss);
c1mi = log(c1miss);
c1v = log(c1vss);
c1y = log(c1yss);
c1rk = log(c1rkss);
c1l = log(c1lss);
c1o = log(c1oss);
c1rrs = c1rrsss;
c1m = log(c1mss);
c1tbal = c1tbalss;
c1gtbal = c1gtbalss;
c1g = log(c1gss);
c1shockgy = c1shockgyss;
c1op = log(c1opss);
c1os = log(c1osss);
c1ow = log(c1owss);
c1rpopd = log(c1rpopdss);
c1oi = log(c1oiss);
c1zc = c1zcss;
c1zclag = c1zclagss;
c1zi = c1ziss;
c1yo = c1yoss;
c1lagyo = c1lagyoss;
c1dyo = c1dyoss;
c1muoc = c1muocss;
c1lagmuoc = c1lagmuocss;
c1muc = c1mucss;
c1omegacm = c1omegacmss;
c1lagomegacm = c1lagomegacmss;
c1omegaim = c1omegaimss;
c2lambdaq = log(c2lambdaqss);
c2q = log(c2qss);
c2i = log(c2iss);
c2k = log(c2kss);
c2c = log(c2css);
c2cne = log(c2cness);
c2cd = log(c2cdss);
c2mc = log(c2mcss);
c2oc = log(c2ocss);
c2id = log(c2idss);
c2rpipd = log(c2rpipdss);
c2mi = log(c2miss);
c2v = log(c2vss);
c2y = log(c2yss);
c2rk = log(c2rkss);
c2l = log(c2lss);
c2o = log(c2oss);
c2rrs = c2rrsss;
c2m = log(c2mss);
c2tbal = c2tbalss;
c2gtbal = c2gtbalss;
c2g = log(c2gss);
c2shockgy = c2shockgyss;
c2op = log(c2opss);
c2os = log(c2osss);
c2ow = log(c2owss);
c2rpopd = log(c2rpopdss);
c2oi = log(c2oiss);
c2zc = c2zcss;
c2zclag = c2zclagss;
c2zi = c2ziss;
c2yo = c2yoss;
c2lagyo = c2lagyoss;
c2dyo = c2dyoss;
c2muoc = c2muocss;
c2lagmuoc = c2lagmuocss;
c2muc = c2mucss;
c2omegacm = c2omegacmss;
c2lagomegacm = c2lagomegacmss;
c2omegaim = c2omegaimss;
c1rer = log(c1rerss);
c2rpwopd = log(c2rpwopdss);
c1rpwopd = log(c1rpwopdss);
c1b = c1bss;
c1rpmcpd = log(c1rpmcpdss);
c2rpmcpd = log(c2rpmcpdss);
c1z = c1zss;
c2z = c2zss;
c1zw = c1zwss;
c1zwlag = c1zwlagss;
c1muo = c1muoss;
c2muo = c2muoss;
c1muow = c1muowss;
c1muowlag = c1muowlagss;
c1rpmipd = log(c1rpmipdss);
c1x = log(c1xss);
c2rpmipd = log(c2rpmipdss);
c2x = log(c2xss);
c2w = log(c2wss);
c1w = log(c1wss);
c2oy = log(c2oyss);
c1oy = log(c1oyss);
c2thetapvar = c2thetapvarss;
c1thetapvar = c1thetapvarss;
c2wdes = log(c2wdesss);
c1wdes = log(c1wdesss);
c2thetawvar = c2thetawvarss;
c1thetawvar = c1thetawvarss;

%country2
c1lambdaq_pot = log(c1lambdaq_potss);
c1q_pot = log(c1q_potss);
c1i_pot = log(c1i_potss);
c1k_pot = log(c1k_potss);
c1c_pot = log(c1c_potss);
c1cne_pot = log(c1cne_potss);
c1cd_pot = log(c1cd_potss);
c1mc_pot = log(c1mc_potss);
c1oc_pot = log(c1oc_potss);
c1id_pot = log(c1id_potss);
c1rpipd_pot = log(c1rpipd_potss);
c1mi_pot = log(c1mi_potss);
c1v_pot = log(c1v_potss);
c1y_pot = log(c1y_potss);
c1rk_pot = log(c1rk_potss);
c1l_pot = log(c1l_potss);
c1o_pot = log(c1o_potss);
c1rrs_pot = c1rrs_potss;
c1m_pot = log(c1m_potss);
c1tbal_pot = c1tbal_potss;
c1g_pot = log(c1g_potss);
c1op_pot = log(c1op_potss);
c1os_pot = log(c1os_potss);
c1ow_pot = log(c1ow_potss);
c1rpopd_pot = log(c1rpopd_potss);
c1oi_pot = log(c1oi_potss);
c2lambdaq_pot = log(c2lambdaq_potss);
c2q_pot = log(c2q_potss);
c2i_pot = log(c2i_potss);
c2k_pot = log(c2k_potss);
c2c_pot = log(c2c_potss);
c2cne_pot = log(c2cne_potss);
c2cd_pot = log(c2cd_potss);
c2mc_pot = log(c2mc_potss);
c2oc_pot = log(c2oc_potss);
c2id_pot = log(c2id_potss);
c2rpipd_pot = log(c2rpipd_potss);
c2mi_pot = log(c2mi_potss);
c2v_pot = log(c2v_potss);
c2y_pot = log(c2y_potss);
c2rk_pot = log(c2rk_potss);
c2l_pot = log(c2l_potss);
c2o_pot = log(c2o_potss);
c2rrs_pot = c2rrs_potss;
c2m_pot = log(c2m_potss);
c2tbal_pot = c2tbal_potss;
c2g_pot = log(c2g_potss);
c2op_pot = log(c2op_potss);
c2os_pot = log(c2os_potss);
c2ow_pot = log(c2ow_potss);
c2rpopd_pot = log(c2rpopd_potss);
c2oi_pot = log(c2oi_potss);
c1rer_pot = log(c1rer_potss);
c2rpwopd_pot = log(c2rpwopd_potss);
c1rpwopd_pot = log(c1rpwopd_potss);
c1b_pot = c1b_potss;
c1rpmcpd_pot = log(c1rpmcpd_potss);
c2rpmcpd_pot = log(c2rpmcpd_potss);
c1rpmipd_pot = log(c1rpmipd_potss);
c1x_pot = log(c1x_potss);
c2rpmipd_pot = log(c2rpmipd_potss);
c2x_pot = log(c2x_potss);
c2w_pot = log(c2w_potss);
c1w_pot = log(c1w_potss);
c2oy_pot = log(c2oy_potss);
c1oy_pot = log(c1oy_potss);
c2rmcpd_pot = log(c2rmcpd_potss);
c1rmcpd_pot = log(c1rmcpd_potss);
c2wdes_pot = log(c2wdes_potss);
c1wdes_pot = log(c1wdes_potss);
c2rpcpd_pot = log(c2rpcpd_potss);
c1rpcpd_pot = log(c1rpcpd_potss);
c2rmcpd = log(c2rmcpdss);
c1rmcpd = log(c1rmcpdss);
c2rpcpd = log(c2rpcpdss);
c1rpcpd = log(c1rpcpdss);
c2dpd = c2dpdss;
c1dpd = c1dpdss;
c2dcore = log(c2pistar);
c1dcore = log(c1pistar);
c1dhead = log(c1pistar);
c1dpwo = log(c1grmuzoss)+log(c1pistar);
c2rpnepd = log(c2rmcpdss);
c1rpnepd = log(c1rmcpdss);
c1rs = c1rsss;
c2rs = c2rsss;
c1pitar = c1pitarss;
c2pitar = c2pitarss;
c1hw = log((1+c1thetaw)/c1thetaw*c1lss/(1-c1xiw*c1beta));
c1gw = log((1+c1tauw)/c1thetaw*c1lss/(1-c1xiw*c1beta));
c1wstar = log(c1wss);
c1omegabar = c1pistar*c1grmuzss;
c1omega = c1pistar*c1grmuzss;
c2hw = log((1+c2thetaw)/c2thetaw*c2lss/(1-c2xiw*c2beta));
c2gw = log((1+c2tauw)/c2thetaw*c2lss/(1-c2xiw*c2beta));
c2wstar = log(c2wss);
c2omegabar = c2pistar*c2grmuzss;
c2omega = c2pistar*c2grmuzss;
c1hp = log(((1+c1thetap)/c1thetap*(c1rmcpdss)*(c1yss)/(1-c1xip*c1beta)));
c1gp = log(((1+c1taup)/c1thetap*(c1yss)/(1-c1xip*c1beta)));
c1pid = c1pistar;
c1pstar = log(1);
c1pidbar = c1pistar;
c2hp = log(((1+c2thetap)/c2thetap*(c2rmcpdss)*(c2yss)/(1-c2xip*c2beta)));
c2gp = log(((1+c2taup)/c2thetap*(c2yss)/(1-c2xip*c2beta)));
c2pid = c2pistar;
c2pstar = log(1);
c2pidbar = c2pistar;
c1yd = log(c1yss);
c2yd = log(c2yss);
c1yd_pot = log(c1yss);
c2yd_pot = log(c2yss);
c1deltad = 0;
c2deltad = 0;
c1ygap = 1;
c1logdeltagdp = c1logdeltagdpss;
c2logdeltagdp = c2logdeltagdpss;
c1rngdpy = c1rngdpyss;
c2rngdpy = c2rngdpyss;
deltalog_gdp_us_obs  =  (c1mugdpss - 1);
deltalog_gdp_for_obs  =  (c2mugdpss - 1);
dpcexfe_log_us_obs  =  log(c1pistar); 
rer_log_us_obs  = log(c1rerss); 
dcomp_log_us_obs  = log(c1pistar*c1grmuzss); 
fedfunds_us_obs  = c1rsss;
fixi_share_us_obs = ((exp(c1rpipd) * exp(c1i)) / exp(c1yd)) / c1rngdpy;    
pce_share_us_obs =  (( (exp(c1rpcpd) * exp(c1c)) / exp(c1yd)) /c1rngdpy);
exp_share_us_obs = ( exp(c1x) / exp(c1yd) ) / c1rngdpy; 
imp_share_us_obs = ( exp(c1m) / exp(c1yd) ) / c1rngdpy; 
oilimp_share_us_obs = exp(c1rpopd)  * (  exp(c1o) / exp(c1y) - exp(c1yo) / exp(c1y)  ) * (1 / c1rngdpy);
oilprod_us_deltalog_obs = ( c1grmuoss  - 1 );
oilprod_for_deltalog_obs = ( c2grmuoss  - 1 );
delta_logoilprice_us_obs = ( c1grmuzoss * c1mugdpss  -  c1grmuzss ) / c1grmuzss; 
fixi_share_for_obs = ((exp(c2rpipd) * exp(c2i)) / exp(c2yd)) / c2rngdpy;    	
imp_share_for_obs = ( exp(c2m) / exp(c2yd) ) / c2rngdpy  ; 	
pce_share_for_obs = (( (exp(c2rpcpd) * exp(c2c)) / exp(c2yd)) /c2rngdpy);	
gov_share_for_obs  = ( exp(c2g)/ exp(c2yd) ) / c2rngdpy; 	
exp_share_for_obs = ( exp(c2x) / exp(c2yd) ) / c2rngdpy; 	
gov_share_us_obs = ( exp(c1g)/ exp(c1yd) ) / c1rngdpy; 	
hours_dlog_us_obs = 0;%log(c1lss); 


for iter = 1:length(M_.params) %update parameters set in the file
  eval([ 'M_.params(' num2str(iter) ') = ' M_.param_names(iter,:) ';' ])
end
NumberOfEndogenousVariables = M_.orig_endo_nbr; %auxiliary variables are set automatically
for ii = 1:NumberOfEndogenousVariables
  varname = deblank(M_.endo_names(ii,:));
  eval(['ys(' int2str(ii) ') = ' varname ';']);
end
